translate.tools.phppo2pypo

Package translate :: Package tools :: Module phppo2pypo |
[hide private]
[frames] | no frames]

# Module phppo2pypo

source code

Convert PHP format .po files to Python format .po files

Classes | [hide private]
| phppo2pypo

Functions | [hide private]
convertphp2py(inputfile, outputfile, template=None) Converts from PHP .po format to Python .po format | source code
main(argv=None) Converts PHP .po files to Python .po files. | source code

Imports: re, sys, po, multistring

Function Details | [hide private]

### convertphp2py(inputfile, outputfile, template=None) | source code
Converts from PHP .po format to Python .po format Parameters: `inputfile` - file handle of the source `outputfile` - file handle to write to `template` - unused